;; INstalls default commands for various file types in dired and action on Enter key;

(require 'string)

(setq dired-guess-shell-alist-user (list 
;;Archives;
  (list "\\.zip$" "unzip")
  (list "\\.rar$" "unrar x")
  (list "\\.tar$" "tar xf")
  (list "\\.tar\\.gz$" "tar xf")
  (list "\\.tar\\.bz2$" "tar xf")
;;Audio files;
  (list "\\.wav$" "musitorius")
  (list "\\.ogg$" "musitorius")
  (list "\\.mp3$" "musitorius")
  (list "\\.ape$" "musitorius")
  (list "\\.flac$" "musitorius")
  (list "\\.wma$" "musitorius")
  (list "\\.m3u$" "musitorius --playlist")
  (list "\\.mid$" "timidity")
  (list "\\.midi$" "timidity")
;;Video files;
  (list "\\.avi$" "show-movie")
  (list "\\.mov$" "show-movie")
  (list "\\.mpg$" "show-movie")
  (list "\\.flv$" "show-movie")
;; Images files;
  (list "\\.bmp$" "show-photo")
  (list "\\.png$" "show-photo")
  (list "\\.jpg$" "show-photo")
  (list "\\.jpeg$" "show-photo")
  (list "\\.gif$" "show-photo")
  (list "\\.tiff$" "show-photo")
;;Documents;
  (list "\\.pdf$" "show-pdf")
  (list "\\.doc$" "antiword")
(list "\\.odt$" "odt2txt")
))

(defun dired-prepare-string-for-shell (s)
  (when s
    (let ((r))
      (if (string-match "\'" s)
	(setq r (string-replace-match "\'" s "\'\\\'\'" t t))
	(setq r s))
      (format "\'%s\'"  r))))

(defun dired-odt2txt (file)
  (set-buffer (get-buffer-create (file-name-nondirectory file)))
  (switch-to-buffer (file-name-nondirectory file))
  (setq buffer-read-only nil)
  (shell-command (format "odt2txt %s" (dired-prepare-string-for-shell file)) (file-name-nondirectory file))
  (setq buffer-read-only t)
  (setq major-mode 'odt2txt-mode)
  (setq mode-name "odt2txt-mode")
  )

(defun dired-antiword (file)
  (set-buffer (get-buffer-create (file-name-nondirectory file)))
  (switch-to-buffer (file-name-nondirectory file))
  (setq buffer-read-only nil)
  (shell-command (format "antiword %s 2> /dev/null" (dired-prepare-string-for-shell file)) (file-name-nondirectory file))
  (setq buffer-read-only t)
  (setq major-mode 'antiword-mode)
  (setq mode-name "antiword-mode")
  )

(defun dired-default-action (file)
(when file (cond
;;Audio files;
    ((string-match "\\.midi$" file)
      (shell-command (format "timidity %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.mid$" file)
      (shell-command (format "timidity %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.m3u$" file)
      (shell-command-to-string (format "musitorius --playlist %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.wav$" file)
      (shell-command-to-string (format "musitorius %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.ogg$" file)
      (shell-command-to-string (format "musitorius %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.mp3$" file)
      (shell-command-to-string (format "musitorius %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.ape$" file)
      (shell-command-to-string (format "musitorius %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.flac$" file)
      (shell-command-to-string (format "musitorius %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.wma$" file)
      (shell-command-to-string (format "musitorius %s > /dev/null 2> /dev/null" (dired-prepare-string-for-shell file))) t)
;;Video files;
    ((string-match "\\.avi$" file)
      (shell-command (format "show-movie %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.mpg$" file)
      (shell-command (format "show-movie %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.flv$" file)
      (shell-command (format "show-movie %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.mov$" file)
      (shell-command (format "show-movie %s" (dired-prepare-string-for-shell file))) t)
;;Image files;
    ((string-match "\\.bmp$" file)
      (shell-command (format "show-photo %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.png$" file)
      (shell-command (format "show-photo %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.jpg$" file)
      (shell-command (format "show-photo %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.jpeg$" file)
      (shell-command (format "show-photo %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.gif$" file)
      (shell-command (format "show-photo %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.tiff$" file)
      (shell-command (format "show-photo %s" (dired-prepare-string-for-shell file))) t)
;;Document files;
    ((string-match "\\.pdf$" file)
      (shell-command (format "show-pdf %s" (dired-prepare-string-for-shell file))) t)
    ((string-match "\\.html$" file)
      (w3m-find-file file) t)
    ((string-match "\\.htm$" file)
      (w3m-find-file file) t)
    ((string-match "\\.odt$" file)
      (dired-odt2txt file) t)
    ((string-match "\\.doc$" file)
      (dired-antiword file) t)
)))

(add-hook 'dired-mode-hook (lambda ()
  (define-key dired-mode-map "\r" (lambda () (interactive) 
    (when (not (dired-default-action (car (dired-get-marked-files))))
      (dired-find-file))
))))
